type Tlogging = 'fatal' | 'error' | 'warn' | 'important' | 'info' | 'success' | 'verbose';
declare class OurLogging {
    #private;
    /**
     * If enabled will sort all new logs in directory by MONTH_YYYY with names DD.log
     * eg October_2022/31.log
     */
    setSeparateLogsByDate(value: boolean): void;


    /**
     * logs by level decrease: 'fatal' | 'error' | 'warn' | 'important' | 'info' | 'success' | 'verbose'
     * @param newLevel log that you want to see in console
     * @example logging.setLogLevel('important')
     * // After that only fatal, error, warn, important logs will shown
     */
    setLogLevel(newLevel: Tlogging): void;


    /**
     * @param path full path to directory where you want to save logs
     */
    setLogPath(path: string): void;


    /**
     * Use only for most important staff like db connection
     * @example throw logging.fatal('DB connection error', err.stack)
     * @returns Error object with text
     */
    fatal(...texts: any[]): Error;


    /**
     * Important but not cicritical errors
     * @returns Error object with error text
     */
    error(...texts: any[]): Error | undefined;


    /**
     * Some suspicious things, noticeable in console
     * EG on server start database logging turn off
     */
    warn(...texts: any[]): void;


    /**
     * Some important things, noticeable in console
     */
    important(...texts: any[]): void;


    /**
     * Not noticeable in console
     */
    info(...texts: any[]): void;


    /**
     * Gray colored log, use it for less important things than info.
     * You can turn off verbose logs (not show it in console, browser, file)
     * by setting log level to success: logging.setLogLevel('success')
     */
    verbose(...texts: any[]): void;


    /**
     * Noticeable in console, green color
     */
    success(...texts: any[]): void;
}
export { OurLogging as LoggingClass }
declare const logging: OurLogging;
export default logging;
